==> aws-java-sdk-lambda-1.9.35-sources.jar: com/amazonaws/services/lambda/invoke/LambdaFunctionError.java <==
/*
 * Copyright 2015-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.lambda.invoke;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Representation of an error from a Lambda function.
 */
class LambdaFunctionError {

    private final String errorType;
    private final String errorMessage;
    private final List<String> stackTrace;

    @JsonCreator
    public LambdaFunctionError(
            @JsonProperty("errorType") String errorType,
            @JsonProperty("errorMessage") String errorMessage,
            @JsonProperty("stackTrace") List<String> stackTrace) {

        this.errorType = errorType;
        this.errorMessage = errorMessage;
        this.stackTrace = stackTrace;
    }

    public String getErrorType() {
        return errorType;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public List<String> getStackTrace() {
        return stackTrace;
    }
}

==> aws-java-sdk-lambda-1.10.25-sources.jar: com/amazonaws/services/lambda/invoke/LambdaFunctionError.java <==
/*
 * Copyright 2015-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.lambda.invoke;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Representation of an error from a Lambda function.
 */
class LambdaFunctionError {

    private final String errorType;
    private final String errorMessage;
    private final List<String> stackTrace;

    @JsonCreator
    public LambdaFunctionError(@JsonProperty("errorType") String errorType,
            @JsonProperty("errorMessage") String errorMessage, @JsonProperty("stackTrace") List<String> stackTrace) {

        this.errorType = errorType;
        this.errorMessage = errorMessage;
        this.stackTrace = stackTrace;
    }

    public String getErrorType() {
        return errorType;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public List<String> getStackTrace() {
        return stackTrace;
    }
}
